::cisco::eem::event_register_syslog pattern "%SYS-5-RESTART" maxrun 60

# _________________________________________________________________________#
# |                                                                       |#
# | mac_init.tcl                                                          |#
# |                                                                       |#
# | by: David Lin                                                         |#
# |  2009, Cisco Systmes, Inc.                                           |#
# |                                                                       |#
# | Version 01.0 10/12/2009                                               |#
# |_______________________________________________________________________|#
# 
# Initializes following parameter while router boots up after RESTART:
#
# 'event manager environment macaddr_old 0000.0000.0000'
#
# macaddr_old is used by mac.tcl to compare MAC address changes
#
# The environment variable 'macaddr_status' is also required.
# macaddr_status is used to lock/unlock the MAC address learned @ bootup
#
# Example configuration:

# event manger directory user policy flash:
# event manager policy mac_init.tcl
# event manager environment macaddr_status unlocked



# Namespace imports

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*


# Open CLI 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli $result
}

if [catch {cli_exec $cli(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "config t"} result] {
    error $result $errorInfo
}

if { $macaddr_status == "unlock" } {


	if [catch {cli_exec $cli(fd) "event manager environment macaddr_old 0000.0000.0000"} result] {
    	error $result $errorInfo
	}

	action_syslog msg "MAC status -> not locked" 

}


if { $macaddr_status == "lock" } {

	action_syslog msg "MAC status -> locked"

}


if [catch {cli_exec $cli(fd) "interface $macaddr_wan_interface"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli(fd) "shut"} result] {
    error $result $errorInfo
}

after 3000

if [catch {cli_exec $cli(fd) "no shut"} result] {
    error $result $errorInfo
}


# Close CLI

if [catch {cli_close $cli(fd) $cli(tty_id)} result] {
    error $result $errorInfo
}
